@@ -15,16 +15,23 @@ from .base import DataModel
 def _generateRandomData(n_rows=100, n_cols=10):
     coltypes = [choice((int, str, float, bool)) for _ in range(n_cols)]
 
-    return np.array([
-        ([_] + [
-            {
-                int: randint(0, 100),
-                str: ''.join(sample(string.ascii_lowercase, 5)),
-                float: (random() * 100) - 50,
-                bool: choice((True, False))
-            }.get(coltypes[_]) for _ in range(n_cols - 1)
-        ]) for _ in range(n_rows)
-    ])
+    return np.array(
+        [
+            (
+                [_]
+                + [
+                    {
+                        int: randint(0, 100),
+                        str: "".join(sample(string.ascii_lowercase, 5)),
+                        float: (random() * 100) - 50,
+                        bool: choice((True, False)),
+                    }.get(coltypes[_])
+                    for _ in range(n_cols - 1)
+                ]
+            )
+            for _ in range(n_rows)
+        ]
+    )
 
 
 class NumpyDataModel(DataModel):
@@ -43,10 +50,18 @@ class NumpyDataModel(DataModel):
         return len(self._data)
 
     def columns(self):
-        return len(self._data[0]) if (self._data is not None and len(self._data) > 0) else 0
+        return (
+            len(self._data[0])
+            if (self._data is not None and len(self._data) > 0)
+            else 0
+        )
 
     def dataslice(self, x0, y0, x1, y1):
-        return self._data[y0:y1 + 1, x0:x1 + 1].T.tolist() if (x0, y0, x1, y1) != (0, 0, 0, 0) else []
+        return (
+            self._data[y0 : y1 + 1, x0 : x1 + 1].T.tolist()
+            if (x0, y0, x1, y1) != (0, 0, 0, 0)
+            else []
+        )
 
     def write(self, x, y, value):
         self._data[y, x] = value
@@ -57,4 +72,4 @@ class NumpyDataModel(DataModel):
         elif data is not None:
             self._data = np.array(data)
         else:
-            raise Exception('Cannot set non-numpy data for numpy data model')
+            raise Exception("Cannot set non-numpy data for numpy data model")
