@@ -8,9 +8,11 @@
 
 
 def _jupyter_nbextension_paths():
-    return [{
-        'section': 'notebook',
-        'src': 'nbextension/static',
-        'dest': 'ipyregulartable',
-        'require': 'ipyregulartable/extension'
-    }]
+    return [
+        {
+            "section": "notebook",
+            "src": "nbextension/static",
+            "dest": "ipyregulartable",
+            "require": "ipyregulartable/extension",
+        }
+    ]
